@@ -618,7 +618,7 @@ function get_size($id, $type, $cfs = '') {
 			$cfs  = db_fetch_cell_prepared('SELECT COUNT(*) FROM data_source_profiles_cf WHERE data_source_profile_id = ?', array($id));
 		}
 
-		$rows = db_fetch_cell_prepared('SELECT SUM(rows) FROM data_source_profiles_rra WHERE data_source_profile_id = ?', array($id));
+		$rows = db_fetch_cell_prepared('SELECT SUM(`rows`) FROM data_source_profiles_rra WHERE data_source_profile_id = ?', array($id));
 
 		return number_format_i18n(($rows * $row * $cfs + $dsheader) / 1000) . " KBytes per Data Source, and $header Bytes for the Header.";
 	} else {
@@ -758,25 +758,27 @@ function profile() {
 						</select>
 					</td>
 					<td>
-						<input type='checkbox' id='has_data' <?php print (get_request_var('has_data') == 'true' ? 'checked':'');?>>
+						<span>
+							<input type='checkbox' id='has_data' <?php print (get_request_var('has_data') == 'true' ? 'checked':'');?>>
+							<label for='has_data'><?php print __('Has Data Sources');?></label>
+						</span>
 					</td>
 					<td>
-						<label for='has_data'><?php print __('Has Data Sources');?></label>
-					</td>
-					<td>
-						<input type='button' id='refresh' value='<?php print __('Go');?>' title='<?php print __('Set/Refresh Filters');?>'>
-					</td>
-					<td>
-						<input type='button' id='clear' value='<?php print __('Clear');?>' title='<?php print __('Clear Filters');?>'>
+						<span>
+							<input type='button' id='refresh' value='<?php print __('Go');?>' title='<?php print __('Set/Refresh Filters');?>'>
+							<input type='button' id='clear' value='<?php print __('Clear');?>' title='<?php print __('Clear Filters');?>'>
+						</span>
 					</td>
 				</tr>
 			</table>
-			<input type='hidden' id='page' name='page' value='<?php print get_request_var('page');?>'>
 			</form>
 			<script type='text/javascript'>
 
 			function applyFilter() {
-				strURL = 'data_source_profiles.php?filter='+escape($('#filter').val())+'&rows='+$('#rows').val()+'&page='+$('#page').val()+'&has_data='+$('#has_data').is(':checked')+'&header=false';
+				strURL  = 'data_source_profiles.php?header=false';
+				strURL += '&filter='+escape($('#filter').val());
+				strURL += '&rows='+$('#rows').val();
+				strURL += '&has_data='+$('#has_data').is(':checked');
 				loadPageNoHeader(strURL);
 			}
 
@@ -825,9 +827,9 @@ function profile() {
 	}
 
 	$total_rows = db_fetch_cell("SELECT
-		COUNT(rows)
+		COUNT(`rows`)
 		FROM (
-			SELECT dsp.id AS rows,
+			SELECT dsp.id AS `rows`,
 			SUM(CASE WHEN local_data_id>0 THEN 1 ELSE 0 END) AS data_sources
 			FROM data_source_profiles AS dsp
 			LEFT JOIN data_template_data AS dtd
