@@ -1268,23 +1268,23 @@ function host() {
 	?>
 	<script type='text/javascript'>
 
+	function applyFilter() {
+		strURL  = 'host.php?host_status=' + $('#host_status').val();
+		strURL += '&host_template_id=' + $('#host_template_id').val();
+		strURL += '&site_id=' + $('#site_id').val();
+		strURL += '&poller_id=' + $('#poller_id').val();
+		strURL += '&rows=' + $('#rows').val();
+		strURL += '&filter=' + escape($('#filter').val());
+		strURL += '&header=false';
+		loadPageNoHeader(strURL);
+	}
+
+	function clearFilter() {
+		strURL = 'host.php?clear=1&header=false';
+		loadPageNoHeader(strURL);
+	}
+
 	$(function() {
-		function applyFilter() {
-			strURL  = 'host.php?host_status=' + $('#host_status').val();
-			strURL += '&host_template_id=' + $('#host_template_id').val();
-			strURL += '&site_id=' + $('#site_id').val();
-			strURL += '&poller_id=' + $('#poller_id').val();
-			strURL += '&rows=' + $('#rows').val();
-			strURL += '&filter=' + escape($('#filter').val());
-			strURL += '&header=false';
-			loadPageNoHeader(strURL);
-		}
-
-		function clearFilter() {
-			strURL = 'host.php?clear=1&header=false';
-			loadPageNoHeader(strURL);
-		}
-
 		$('#rows, #site_id, #poller_id, #host_template_id, #host_status').change(function() {
 			applyFilter();
 		});
@@ -1368,10 +1368,10 @@ function host() {
 						</select>
 					</td>
 					<td>
-						<input type='button' id='refresh' value='<?php print __('Go');?>' title='<?php print __('Set/Refresh Filters');?>'>
-					</td>
-					<td>
-						<input type='button' id='clear' value='<?php print __('Clear');?>' title='<?php print __('Clear Filters');?>'>
+						<span>
+							<input type='button' id='refresh' value='<?php print __('Go');?>' title='<?php print __('Set/Refresh Filters');?>'>
+							<input type='button' id='clear' value='<?php print __('Clear');?>' title='<?php print __('Clear Filters');?>'>
+						</span>
 					</td>
 				</tr>
 			</table>
@@ -1415,7 +1415,6 @@ function host() {
 					</td>
 				</tr>
 			</table>
-			<input type='hidden' id='page' value='<?php print get_request_var('page');?>'>
 		</form>
 		</td>
 	</tr>
