@@ -206,7 +206,7 @@ function clog_view_logfile() {
 	$tail_lines   = get_request_var('tail_lines');
 	$base_url     = 'clog.php?rfilter='.$rfilter.'&reverse='.$reverse.'&refresh='.$refreshTime.'&message_type='.$message_type.'&tail_lines='.$tail_lines.'&filename='.basename($logfile);
 
-	$nav          = html_nav_bar($base_url, MAX_DISPLAY_PAGES, $page_nr, $number_of_lines, $total_rows, 13, __('Entries'), 'page');
+	$nav = html_nav_bar($base_url, MAX_DISPLAY_PAGES, $page_nr, $number_of_lines, $total_rows, 13, __('Entries'), 'page', 'main');
 
 	echo $nav;
 
@@ -322,33 +322,49 @@ function filter($clogAdmin) {
 			<table class='filterTable'>
 				<tr>
 					<td>
-						<?php print __('File to show');?>
+						<?php print __('File');?>
 					</td>
 					<td>
-						<select id='filename' name='filename'>
-							<?php
-							$configLogPath = read_config_option('path_cactilog');
+						<?php
+						$configLogPath = read_config_option('path_cactilog');
 
-							if ($configLogPath == '') {
-								$logPath = $config['base_path'] . '/log/';
-							} else {
-								$logPath = dirname($configLogPath);
-							}
+						if ($configLogPath == '') {
+							$logPath = $config['base_path'] . '/log/';
+						} else {
+							$logPath = dirname($configLogPath);
+						}
 
+						if (is_readable($logPath)) {
+							$files = scandir($logPath);
+						} else {
+							$files = false;
+						}
+
+						if ($files === false) {
+							echo '<select id="filename" name="filename">
+									<option value="cacti.log">cacti.log</option>';
+						} else {
+							echo '<select id="filename" name="filename">';
 							$selectedFile = basename(get_nfilter_request_var('filename'));
-							$files        = scandir($logPath);
 
 							foreach ($files as $logFile) {
 								if (in_array($logFile, array('.', '..', '.htaccess'))) {
 									continue;
 								}
+
+								$explode = explode('.', $logFile);
+								if (substr($explode[max(array_keys($explode))], 0, 3) != 'log') {
+									continue;
+								}
+
 								print "<option value='" . $logFile . "'";
 								if ($selectedFile == $logFile) {
 									print ' selected';
 								}
 								print '>' . $logFile . "</option>\n";
 							}
-							?>
+						}
+						?>
 						</select>
 					</td>
 					<td>
@@ -368,18 +384,18 @@ function filter($clogAdmin) {
 						</select>
 					</td>
 					<td>
-						<input type='button' id='go' name='go' value='<?php print __('Go');?>'>
-					</td>
-					<td>
-						<input type='button' id='clear' name='clear' value='<?php print __('Clear');?>'>
-					</td>
-					<td>
+						<span>
+							<input type='button' id='go' name='go' value='<?php print __('Go');?>'>
+							<input type='button' id='clear' name='clear' value='<?php print __('Clear');?>'>
 						<?php if ($clogAdmin) {?><input type='button' id='purge' name='purge' value='<?php print __('Purge');?>'><?php }?>
+						</span>
 					</td>
 				</tr>
+			</table>
+			<table class='filterTable'>
 				<tr>
-					<td class='nowrap'>
-						<?php print __('Message Type');?>
+					<td>
+						<?php print __('Type');?>
 					</td>
 					<td>
 						<select id='message_type' name='message_type'>
@@ -391,7 +407,7 @@ function filter($clogAdmin) {
 							<option value='5'<?php if (get_request_var('message_type') == '5') {?> selected<?php }?>><?php print __('SQL Calls');?></option>
 						</select>
 					</td>
-					<td class='nowrap'>
+					<td>
 						<?php print __('Display Order');?>
 					</td>
 					<td>
@@ -400,8 +416,6 @@ function filter($clogAdmin) {
 							<option value='2'<?php if (get_request_var('reverse') == '2') {?> selected<?php }?>><?php print __('Oldest First');?></option>
 						</select>
 					</td>
-				</tr>
-				<tr>
 					<td>
 						<?php print __('Refresh');?>
 					</td>
